@@ -1,12 +1,11 @@
 """
 General helpers required for `tqdm.std`.
 """
-from functools import wraps
-from warnings import warn
 import os
 import re
-import subprocess
 import sys
+from functools import wraps
+from warnings import warn
 
 # py2/3 compat
 try:
@@ -53,7 +52,7 @@ class FormatReplace(object):
     >>> a = FormatReplace('something')
     >>> "{:5d}".format(a)
     'something'
-    """
+    """  # NOQA: P102
     def __init__(self, replace=''):
         self.replace = replace
         self.format_called = 0
@@ -141,7 +140,7 @@ class DisableOnWriteError(ObjectWrapper):
         def inner(*args, **kwargs):
             try:
                 return func(*args, **kwargs)
-            except (IOError, OSError) as e:
+            except OSError as e:
                 if e.errno != 5:
                     raise
                 tqdm_instance.miniters = float('inf')
@@ -154,11 +153,11 @@ class DisableOnWriteError(ObjectWrapper):
     def __init__(self, wrapped, tqdm_instance):
         super(DisableOnWriteError, self).__init__(wrapped)
         if hasattr(wrapped, 'write'):
-            self.wrapper_setattr('write', self.disable_on_exception(
-                tqdm_instance, wrapped.write))
+            self.wrapper_setattr(
+                'write', self.disable_on_exception(tqdm_instance, wrapped.write))
         if hasattr(wrapped, 'flush'):
-            self.wrapper_setattr('flush', self.disable_on_exception(
-                tqdm_instance, wrapped.flush))
+            self.wrapper_setattr(
+                'flush', self.disable_on_exception(tqdm_instance, wrapped.flush))
 
     def __eq__(self, other):
         return self._wrapped == getattr(other, '_wrapped', other)
@@ -198,7 +197,7 @@ def _is_utf(encoding):
     except Exception:
         try:
             return encoding.lower().startswith('utf-') or ('U8' == encoding)
-        except:
+        except Exception:
             return False
     else:
         return True
@@ -237,8 +236,8 @@ def _screen_shape_wrapper():  # pragma: no cover
 
 def _screen_shape_windows(fp):  # pragma: no cover
     try:
-        from ctypes import windll, create_string_buffer
         import struct
+        from ctypes import create_string_buffer, windll
         from sys import stdin, stdout
 
         io_handle = -12  # assume stderr
@@ -254,7 +253,7 @@ def _screen_shape_windows(fp):  # pragma: no cover
             (_bufx, _bufy, _curx, _cury, _wattr, left, top, right, bottom,
              _maxx, _maxy) = struct.unpack("hhhhHhhhhhh", csbi.raw)
             return right - left, bottom - top  # +1
-    except:
+    except Exception:  # nosec
         pass
     return None, None
 
@@ -263,9 +262,10 @@ def _screen_shape_tput(*_):  # pragma: no cover
     """cygwin xterm (windows)"""
     try:
         import shlex
-        return [int(subprocess.check_call(shlex.split('tput ' + i))) - 1
+        from subprocess import check_call  # nosec
+        return [int(check_call(shlex.split('tput ' + i))) - 1
                 for i in ('cols', 'lines')]
-    except:
+    except Exception:  # nosec
         pass
     return None, None
 
@@ -273,19 +273,19 @@ def _screen_shape_tput(*_):  # pragma: no cover
 def _screen_shape_linux(fp):  # pragma: no cover
 
     try:
-        from termios import TIOCGWINSZ
-        from fcntl import ioctl
         from array import array
+        from fcntl import ioctl
+        from termios import TIOCGWINSZ
     except ImportError:
         return None
     else:
         try:
             rows, cols = array('h', ioctl(fp, TIOCGWINSZ, '\0' * 8))[:2]
             return cols, rows
-        except:
+        except Exception:
             try:
                 return [int(os.environ[i]) - 1 for i in ("COLUMNS", "LINES")]
-            except KeyError:
+            except (KeyError, ValueError):
                 return None, None
 
 
@@ -318,8 +318,7 @@ except ImportError:
     _text_width = len
 else:
     def _text_width(s):
-        return sum(
-            2 if east_asian_width(ch) in 'FW' else 1 for ch in _unicode(s))
+        return sum(2 if east_asian_width(ch) in 'FW' else 1 for ch in _unicode(s))
 
 
 def disp_len(data):
